pub enum MetadataConversionError {
WrongType {
expected: &'static str,
found: &'static str,
},
NumberOutOfRange {
expected: &'static str,
found: Number,
},
FloatNotRepresentable,
}Expand description
Error type returned when attempting to convert (try_into) a MetadataValue
into a concrete type and the value does not have the expected shape.
Variants
WrongType
NumberOutOfRange
FloatNotRepresentable
Returned when a floating point number cannot be represented (unlikely here, but preserved for completeness).