Generic, arbitrarily nested metadata map structure that can be attached to
configuration structs. Each value can be a string, number, list or another map.
This provides an escape hatch for custom configuration without changing the
strongly typed configuration surface.